netapp_ontap.models.ems_filter_rules API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ems_filter_rules`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EmsFilterRulesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EmsFilterRules object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `index: Size GET POST PATCH`

    Rule index. Rules are evaluated in ascending order. If a rule's index order is not specified during creation, the rule is appended to the end of the list.

    Example: 1

  `links: SelfLink GET`

    The links field of the ems_filter_rules.

  `message_criteria: EmsFilterRulesMessageCriteria GET POST PATCH`

    Matching message definitions for the filter. A property must be specified.

  `parameter_criteria: List[EmsParameterCriterion] GET POST PATCH`

    Parameter criteria used to match against events' parameters. Each parameter consists of a name and a value. When multiple parameter criteria are provided in a rule, all must match for the rule to be considered matched. A pattern can include one or more wildcard '*' characters.

  `type: str GET POST PATCH`

    Rule type

    Valid choices:

    - include
    - exclude